@@ -14,7 +14,7 @@ Usage::
     client: QLDBClient = boto3.client("qldb")
     session_client: QLDBClient = session.client("qldb")
 """
-from mypy_boto3_qldb.client import QLDBClient, QLDBClient as Client
+from mypy_boto3_qldb.client import QLDBClient as Client, QLDBClient
 
 
 __all__ = ("Client", "QLDBClient")
